summaryrefslogtreecommitdiffstats
path: root/src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp')
-rw-r--r--src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp b/src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp
index f329da66ef..f45b232a91 100644
--- a/src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp
+++ b/src/network/doc/snippets/code/src_network_kernel_qhostinfo.cpp
@@ -39,8 +39,8 @@
****************************************************************************/
//! [0]
-// To find the IP address of qt.nokia.com
-QHostInfo::lookupHost("qt.nokia.com",
+// To find the IP address of qt-project.org
+QHostInfo::lookupHost("qt-project.org",
this, SLOT(printResults(QHostInfo)));
// To find the host name for 4.2.2.1
@@ -50,7 +50,7 @@ QHostInfo::lookupHost("4.2.2.1",
//! [1]
-QHostInfo info = QHostInfo::fromName("qt.nokia.com");
+QHostInfo info = QHostInfo::fromName("qt-project.org");
//! [1]